AnalyticApiParameterNameModel class
Constructors
- AnalyticApiParameterNameModel({required String sessionId, required String uuid, required String eventCode, required String eventName, required String eventType, required String eventTime, required String userIp, required String countryCode, required String cityCode, required String systemVersion, required String appVersion, required String attrPage, required String eventContent, required String env})
Properties
- appVersion → String
-
final
- attrPage → String
-
final
- cityCode → String
-
final
- countryCode → String
-
final
- env → String
-
final
- eventCode → String
-
final
- eventContent → String
-
final
- eventName → String
-
final
- eventTime → String
-
final
- eventType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- systemVersion → String
-
final
- userIp → String
-
final
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited